package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!0````!$``60````#0``+)<```````T`"``
M"``H`!P`&P````8````T$```-!```#0```$````!``````4````$`````P``
M`300``$T$``!-`````T````-````!`````$````!`````!`````0``````"K
M?```JWP````%``$```````$``*[8$`&NV!`!KM@```)(```2@`````8``0``
M`````@``KO`0`:[P$`&N\````0````$`````!@````0````$```!1!```400
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``KM@0`:[8$`&NV````2@```$H````!`````$O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@```"`````$
M````%`````-'3E4`V1+PY/>YD@"#@`VI#<72IPSNL<8````E````10````@`
M```(!!`<`(($0"4`0``XJ`&&H@(``<`I!"A+1S*B.`@,!(H```!%````1@``
M`````````````````$@```!*````2P````````!,````30```$\```!0````
M40```%(`````````5```````````````50```%8```!9``````````````!:
M````7````%T```!?`````````&$```!C``````````````!E````9@```&<`
M````<;+5R2U'WLY)^^"C#N_3ZFNCW:>VF\4OGN/-VX&<^8>6FZ16UD,):QR+
M\CD+ESH-D`6)Q9[B%`S3<`>)#N3_(5<0B@M`G+G$?)I_:F^+`;.;G*E_']_%
M;AQ8<=E\DN.[P.-+K'S49-4*`J?@[=MB,VM*\'IFS*]G[-5%0@'&1^/%CD%]
M+#_EPQW3V_)@;*'Z#O&-N0````````````````````````+G```````````2
M```````#C0``````````$@```````B0``````````!(````````1````````
M```@```````#^P``````````$@```````WX``````````!(```````$]````
M```````2```````#`@``````````$@```````-,``````````!(```````+N
M```````````2````````KP``````````$@```````3@``````````!(`````
M``*>```````````2```````#.P``````````$@```````J\``````````!(`
M``````&A```````````2```````#2P``````````$@```````T(`````````
M`!(```````%A```````````2````````X0``````````$@```````>L`````
M`````!(```````&(```````````2```````";0``````````$@```````AP`
M`````````!(```````++```````````2```````!V```````````$@``````
M`KP``````````!(```````'D```````````2```````!;P``````````$@``
M`````U(``````````!(````````M```````````@```````"?P``````````
M$@```````U\``````````!(```````!X```````````2```````"V0``````
M````$@```````Y0``````````!(```````(5```````````2```````!#P``
M````````$@```````W```````````!(```````"^```````````2```````!
ME@``````````$@```````N```````````!(```````*V```````````2````
M```"C```````````$@```````CT``````````!(```````+$```````````2
M````````:@``````````$@```````4(``````````!(```````,)````````
M```2```````!S0``````````$@```````O0``````````!(```````$<````
M```````2```````#A@``````````$@```````M(``````````!(```````&O
M```````````2````````/```````````(````````/,``````````!(`````
M``%_```````````2```````#9@``````````$@```````(<``````````!(`
M``````!0```````````@```````"A```````````$@```````RH`````````
M`!(```````(I```````````2```````#%P``````````$@```````DX`````
M`````!(```````*5```````````2```````#(@``````````$@```````4X0
M`&A``````!(```````0I$`!3$```"WP2```,```$<Q``3B````)4$@``#```
M`](0`&L0`````!(```T```.H$`&Q(`````0A```9```#V!``28`````,$@``
M#```!%D0`&2P````P!(```P```">$`!I```````2```````!+1`!L2@````$
M$0``&0``!#80`;$0`````!```!<```,T$`&Q)`````01```9```$.!`!L1``
M````(```%P```Z<0`;$@````!"$``!D```/($`!E<`````02```,```$:1`!
ML1P````$$0``&```!(@0`$F0```"8!(```P```$"$`&Q+`````$1```9```#
MIA`!L2`````$$0``&0```Z$0`!/````"@!(```P```2G$`!0@````+`2```,
M```#Z1``43`````X$@``#```!`00`&,P````V!(```P```.W$`&Q(``````0
M```9```#PQ`!P5@`````$```&0```EX0`&M0````!!$```X```31$`!>D```
M!)P2```,```$0Q``2+````#,$@``#```!#P0`!9`````)!(```P```&]$`!F
M```````2```````$'1``3%````'0$@``#````[`0`;$@`````!```!@```00
M$`!+\````%02```,```$M1``9!````!,$@``#```!(`0`$@0````0!(```P`
M``'V$`&Q,````!,1```9```$E1``47````&<$@``#```!((0`!-\`````!(`
M``L`;&EB<&5R;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF
M=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I
M;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV
M-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S<&5C:69I8P!?7V5R<FYO7VQO
M8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES
M=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S
M=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T
M<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN
M=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I
M<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M
M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`
M7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U
M7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD
M<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R
M;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)
M0D-?,BXR`$=,24)#7S(N,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C0```````(``@`#`````@`"``(``@````(```````0``@`"`````@`"
M````````````!0`&``(````"``(````'`````@`"`````@`"``8````$````
M```"``(``@`#``(```````<````$`````@`"````````````"````````@`(
M``,`"``#``(``@````$``0`!``(``0`!```````!``(``0`"``$``0`!````
M`@`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!`````0`"
M```"!0```!`````P#6EI$@````8```3G````$`UI:1`````#```$\0``````
M`0`%```"5````!``````#6EI$@````@```3G````$`EI&70````'```$^P``
M`!`):1ER````!0``!0<````0#6EI%`````0```43````$`UI:1`````"```$
M\0`````0`:_P```?%``````0`;$@``!6$P`````0`;$D``!/$P`````0`;$H
M``!-$P`````0`;$L``!5$P`````0`;$P``!G$P`````0`;`````!%0`````0
M`;`$```"%0`````0`;`(```#%0`````0`;`,```%%0`````0`;`0```&%0``
M```0`;`4```'%0`````0`;`8```(%0`````0`;`<```)%0`````0`;`@``!A
M%0`````0`;`D```*%0`````0`;`H```+%0`````0`;`L```,%0`````0`;`P
M```-%0`````0`;`T```.%0`````0`;`X```/%0`````0`;`\```0%0`````0
M`;!````1%0`````0`;!$```2%0`````0`;!(```3%0`````0`;!,```4%0``
M```0`;!0```5%0`````0`;!4```6%0`````0`;!8```7%0`````0`;!<```8
M%0`````0`;!@```9%0`````0`;!D```:%0`````0`;!H```;%0`````0`;!L
M```<%0`````0`;!P```=%0`````0`;!T```>%0`````0`;!X```?%0`````0
M`;!\```@%0`````0`;"````A%0`````0`;"$```B%0`````0`;"(```C%0``
M```0`;",```D%0`````0`;"0```E%0`````0`;"4```F%0`````0`;"8```G
M%0`````0`;"<```H%0`````0`;"@```I%0`````0`;"D```J%0`````0`;"H
M```K%0`````0`;"L```L%0`````0`;"P``!%%0`````0`;"T```M%0`````0
M`;"X```N%0`````0`;"\```O%0`````0`;#````P%0`````0`;#$```Q%0``
M```0`;#(```R%0`````0`;#,```S%0`````0`;#0```T%0`````0`;#4```U
M%0`````0`;#8```V%0`````0`;#<```W%0`````0`;#@``!,%0`````0`;#D
M```Y%0`````0`;#H```Z%0`````0`;#L```[%0`````0`;#P```\%0`````0
M`;#T```^%0`````0`;#X```_%0`````0`;#\``!`%0`````0`;$```!!%0``
M```0`;$$``!"%0`````0`;$(``!#%0`````0`;$,``!$%0````"4(?_P?`@"
MII`!`!23P0`(0I\`!7_(`J8_W@`".]Z<9(`>__PO@```0;X`"$@`4[F``0`4
M?`@#IH/!``@X(0`03H``()0A_\!\"`*FD\$`.)`!`$23X0`\D&$`')"!`!B0
MH0`4.&$`'#B!`!@XH0`4/^`0`H$BC_B1(0`L.2```$@`4Y4\@!``.(1H0#Q@
M$`!\A2-X.&-I`$@`4$T](!`"B\FQ+"^>``!`G@`L2`!2F3U`$`(O@P``D&K!
M5$&>`@`_X!`"2`!1X8!_L2A(`%4IF\,'!8!_L2A(`%4=B2,$MGQJ&WB`?[$H
M82D``IDJ!+9(`%4%@2$`'(E#!+8Y*0`%84H``9E#!+8]0$,PD4$`")$A``P]
M0!``P`IKT#U`$`#)80`(_8L`*,@*:]@]0!``_`P`*LF*:^#_@&``09T!/%4C
M$#H_X!`"2`!238%!`!B`H0`</0`0`CO_L42!"+$<@2H``"^%``%\:QMXD'\0
M")$#``B1(P``/2`0`#DI;OR1(P`$/2`0`#DI;P"1(P`,.2``!)$_$`1`G0`H
M5*D0.CD#``PY*?_X52GPOCDI``%]*0.FA2H`!)4H``1"`/_X5*D0.H!_$!`\
M@!``.2D`##E````XA$A0.*4``WUF6W@XX```?4M)+D@`4SU\?AMY08(`9(!_
M$!!(`%#]/&`0`#B!`"@X8VRL3,8Q@D@`*1DO@P``09X`4(!_$!!(`%"92`!2
MU7_#\WB!(0`L@4*/^'TI4GDY0```0((`@(`!`$2#P0`X@^$`/#@A`$!\"`.F
M3H``((!_$!!(`%--?'X;>$O__Y2`?Q`,+X,``$&>`"1(`$U%2___I#Q@$``\
M@!`".&-MV#B$L3!,QC&"2`!1Z3Q@$``X@0`H.&-L2$S&,8)(`"B%+X,``)!_
M$`Q!GO]L2`!-!4O__V1(`%`-.&```4@`435\*0MX5"$`-C@```"4(?_P?`@#
MII`!```]`!``A:AK0$@`45`````````````````](!`"/&`0`CDIL1PX8[$<
M.2D``WTC2%`KB0`&3)T`(#T@```Y*0``+XD``$V>`"!]*0.F3H`$(&````!@
M````/&`0`CR`$`(X8[$<.(2Q''R#(%!\A!9P?(0.<'R$`95-@@`@/4```#E*
M```OB@``39X`('U)`Z9.@`0@8````)0A__!\"`*FD^$`##_@$`*)/[%#D`$`
M%"^)``!`G@`02___83D@``&9/[%#@`$`%(/A``PX(0`0?`@#IDZ``"`](!`"
M.2FNX'TC2WB!(P``+XD``$">``Q+__]H8````#T@```Y*0``+XD``$&>_^R4
M(?_P?`@"IGTI`Z:0`0`43H`$(8`!`!0X(0`0?`@#IDO__S``````````````
M````````````````````````E"'[4'QL&WA\"`*F.4,`,#A@``A\:0.F.0``
M`)`!!+21P01HD>$$;)(!!'"2(01TDD$$>))A!'R2@02`DJ$$A)+!!(B2X02,
MDP$$D),A!)230028DV$$G).!!*"3H02DD\$$J)/A!*PY(0'8@`*/^)`!!%PX
M````8````&````"$R@`(D0D``(#J``20R0`$.2D`$)$)__B0Z?_\0@#_Y#B@
M`$`X@0(X?*D#ICA@```XA``(@.3_V($$``2!)/_<@40``("D_ZB`Q/^L?.I2
M>'TI0GB`Y/^<@03_F'U**GA]*3)X?4I">'TI.GA52@@\52D(/GTI4WB09``8
MD20`'$(`_["!3``@@6P`)#T@6H([0```@,$!V(#A`=QA*7F9.\```(',`!B!
M[``<?.=8%'S&412`@0'@@*$!Y((L`!R"3``4?6=*%'RE>!1\A'$4@>P`#((,
M``A]!U@0?0A!$()L`!""C```?.5*%(+!`>B"X0'L?,HS>'T(`-!^(WAX?4A2
M%'RE.!!\I2D0?DAX.'W<@'B!S```?'E#>'R&(WB`;``$@(P``'RE`-!^?8`X
M?G6@>'S%,A14D_`"5<4H-%1D*#Y_F.MX@ZP`%(.,`!!\FRMX5>#P`GRKV!1\
MBM$45@OP`E7J\+Z![``$?O?H%'[6X11]:E-X?5\#>%1H\+Y_RG`X?*7(%'R$
MP11_=TH4?5RK>'^T&'A_ZG@X@&$!]'YH0WA5X/`"?0L#>'U=HWB"@0'P.4``
M`'P7V!!\``$0?(A0.'SGZ!1\QN$4?J-*%'_W*'A\I%@X5+,H/GT8\W@Z0```
M@0$!_'P``-!^VK-X?.>8%'S&D11_0-(4?ODC>'QCJ!!\8QD05+;P`G\YV!1_
M&-$4@T$!^']H2A14I?"^.X```'R]LWA4]R@^?&,`T#K```!]"-@0?0A!$'\Y
MN!1_&+$4?6`X>'Z#HA1\P^`X?.;H.'__J!1_WJ$4?&13>(!A`@1\!3-X?0@`
MT#C```!_2-(45/?POG\(,#A4X/`"?6O8%'U*T11^YP-X?13C>'[_*!1^WB$4
M5RCPOH"!`@!\HTH45SKP`G^[R'A_(#@X?&,H$'QC&1!7/R@^.\```'T9TWB!
M`0(,?_^X%'_>L11_=0-X@L$""'[H2A0[````?K58%'Z4411\8P#0?(,B%%?[
M*#Y_P\`X.T```'T(N!!]"$$0?K78%'Z4T11\:C-X?[TH%'^<(12`80(4?.3X
M>'_ER#A]"`#0?(LK>#B```!7_O"^5^#P`G^]6!1_G%$4?LBR%(%!`A!]8TH4
M?H@@.'_%`WA]&L-X5K\H/GSGN!1\QK$45JCPOE:V\`([P```?&-8$'QC&1!_
MO?@4?YSQ%'\WJ'A]'[-X?J`H.($!`AQ^^P-X?&,`T'SGV!1\QM$4.\```']H
M2A1]0U(4?0C8$'T(01!_@_`X?SE8%'\84117M2@^?*OH>'^J^#@Z@```?K4X
M%'Z4,11\=B-X@&$")(-!`AA]=U-X?SFX%'\8L10Y0```?0@`T%>F\+Y7I_`"
M?TC2%%:]*#Y^B%`X.X```'\YZ!1_&.$4?,L[>(#!`B!\XTH4?1;S>%:\\`)6
MJ/"^?*78%'R$T11__:AX?J!8.'QC.!!\8QD0?17C>($!`BR#@0(H?[<#>'QC
M`-!_J$H4?O<H%'[6(10Z@```?,,R%%<[*#X[0```?0CH$'T(01!^]]@4?M;1
M%'\#H#A__S@4?]XQ%'UFR'A_)Z@X?&13>'S%.WB`80(T.,```'T(`-!7._"^
M5R#P`G__*!1_WB$4?XCB%("!`C!^R#`X?V<#>'T8HWA\HTH45OLH/GUKZ!1]
M2N$45NCPOE;\\`([0```?KVX>'__V!1_WM$4?N`X.'T;XWB!`0(\?&,H$'QC
M&1!_N0-X?6O(%'U*P12#`0(X?RA*%'QC`-`[0```?(,B%'T(R!!]"$$05_TH
M/CN```!_P]`X?[U8%'^<411\_OAX?^#8.'REJ!1\A*$4?'8S>(!A`D1_UP-X
M5^OPOCO```!7ZO`"?0@`T'U_4WA\I;@4?(2Q%(%!`D!_",(4?XCP.'^@^#A_
M?.AX?133>%>W*#Y7J/"^.L```%>]\`)\I;@4?(2Q%'UC2A1]%^MX@0$"3'SG
MR!1\QL$4?&-8$'QC&1"#`0)(?Y4#>'\H2A1\YZ@4?,:A%'QC`-!]",@0?0A!
M$#K```!4M2@^.H```'U#4A1\YZ@4?,:A%'R#L#A_X"AX?*2X.'UKV!1]2M$4
M?0@`T'Q\\WB`80)4?!TC>#J```!_",(45*3POGXY^!1^&/$4?,B@.(#!`ER#
M`0)@?6OH%'U*X12#@0)05*7P`GR5*WA4Y2@^.(```#M```!]:R@4?4HA%)(A
M`$2"(0)D?*9*%("!`EA_HTH4?,8H$'S&,1"300`0?S%*%'QCZ!!\8QD0?,8`
MT'XQR!!^,8D0?(8B%(#!`FQ\8P#0.>```'YEJ!1^1*$4?X/B%%5E\`)59/"^
M5.[POGXQ`-`[P```D>$`6%3O\`)_$<(4?<][>'R1*WB`@0)H?*9*%)/!`!@[
M8```?_VX%'_<L10[@```?&8H$'QC&1"2`0!`@,$"=))!`+"280"TDT$`8)-A
M`""3@0!HD>$`%(.A`!!^H%AX57,H/GQC`-"!P0*`?4KH.#H```!]7*-X?6IX
M.(*!`GA\'5-X?(,B%(!A`$!]??@4?5SQ%(.!`!"#H0`4.D```']YZ!1_6.$4
MD6$`S'UF2A2!(0)\DT$`N'T:LW@]`&[9?\6(%'^D@12`@0!$80CKH7SEJ#A^
MJ4(4?,98$'S&,1!]*:@0?2E)$)%!`,B!00)P?,8`T'TI`-!^YSAX?492%'Z)
MHA2`P0*$@2$"C)-A`+R3P0!4?/LK>#O```"`X0*4?>9"%)/!`'!_Y-@4?\/1
M%']I0A2#00*(?,9X$'S&,1!]*=@0?2E)$'__F!1_WI$4@D$`&'S&`-!]*0#0
M?<9R%'])TA17YO`"5^GPOCB```!])C-X.X```($A`IR0P0`<D($`0#K````X
M8```.(```).A`%"3@0!XDL$`@).!`(B080"8D($`D(+!`I`X@```@F$`''[G
M0A0X8```?.>X$'SG.1`[````?,N8%'RJD11_ZH@XD*$`P)#!`,23@0"@@*$`
M$'_&@#B!80`4@X$`L'SG`-!^:4(4?,8K>(.A`+20@0#0D,$`*'UF^'B#P0#(
M?,I3>'['LA2`P0!8@`$`&)%!`"Q]*9@0?2E)$()!`IB080"H?2D`T'Y)DA2!
M00`H@6$`+'R]6!1\G%$45^LH/H/A`,R180!<8$(``(#A`%Q_OS@4?YXQ%#O`
M``"`X0*DD\$`6(/!`"!7IO"^5ZKP`GS*4WA_B0`XD4$`)'TI@WB"`0"XD2$`
M,'XIZ'B"(0"\.X```(/A`"1]=?@4?53Q%(*A`!PZ@```DH$`L(*!`#"100#(
M.4```)%!`!!_JJ@X?2I3>)%A`,R100`T?^="%'SG^!!\YSD0?.<`T(*A`#2`
MP0*L@\$"H(`!`"!]<:@4?5"A%%>Q*#Z"@0!@DB$`9((A`%1_Q_(4.@```)(!
M`+@Z````D@$`8((!`%!_ID(4?,;H$'S&,1"3@0`H@X$"J(*A`&1\Q@#0?X;B
M%'REJ!1\A*$45*/P`E2I\+Y]*1MX?(<`.("!`&A].4MX?J_(%'Z.P12!P0`8
M@>$`')*A`#2"H0`D?.=S>)#A`#A]YRAX?*.H.)*!`#!\XQMXD&$`/(!A`K2!
MP0`X8$(``('A`#Q^L7@4?I!Q%%2P*#Z2`0!L.>```#G```"1X0!0D<$`V('!
M`)A^(T(4?&.($'QC&1"`H0!L?&,`T'UK*!1]2B$4.(```)"!`&A59?"^56?P
M`GRG.WA]6,`XD.$`G'SI2GA@0@``@>$`G'S;>!1\NG$4.T```)"A`!B0P0`<
M@`$"O("!`"1]9L@X@V$`(('!`,!\BEAX@>$`Q((!`K!_&-MX?48S>),!`$B0
MP0!,?@."%(#!`L2300"8@T$"N']@0A1\`-@0?``!$'P``-"#`0!(@R$`3']`
MTA1\K\@4?([!%%5O*#Z#`0!PD>$`=#L@```YP```DR$`P)'!`$@YP```D<$`
M<)'!`."!P0"H@R$`='UUR!1]5,$4.H```)*!`.A58_"^56KP`GQJ4WA]*5IX
MD4$`K)$A`$1]1SIX?R9"%'S&R!!\QC$0?,8`T('A`*Q^MW@4?I9Q%(+!`,B!
MP0!`@>$`1(+A`,R2@0%(DJ$!3'ZW>!1^EG$456\H/H+!`'B1X0!\.<```&!"
M``""X0!\D<$`>($A`LR#`0+`?*6X%'R$L10ZP```?NE"%%2C\+Y4I/`"?&0C
M>'SG*GB`80+4D($`%)#A`(Q\@%)X.4```)%!`$"!00`0?2FX$'TI21"2P0"H
M@L$"R'TI`-!_!L(4?LFR%($A`"@XP```@6$`%)#!`,A\XT(4?&,X$'QC&1!]
M\U@4?=)1%(%!`(B"00`P@F$`-(%A`(Q\8P#0D<$!4)'A`51]\U@4?=)1%%2K
M*#Z"00"`D6$`A#B@```Y0```D*$`@)%!`(B"80"$?K68%'Z4D10Z@```5JOP
MOE:E\`)]92MX?`"J>(%A`!R0H0`L?*0B>)"!`6"0`0"D@4$`+'Y_4!1^7DD4
M@4$`&))!`5B280%<@\$`H(/A`*2!(0"0@($"['YK^!1^2O$45K\H/H`!`MR`
MP0+0D^$`E(/A`N0[P```DH$`\'__0A23P0"@D^$`%(/A`O1^H$(4D\$!"#O`
M``"3P0$0D\$!&(%!`)1\`*@0?``!$'S#,A1][U`4?<Y)%#E```"100"0?41"
M%#D@``"100`<?5]"%)%!`"2!00+\?```T)$A`/B1(0$`?4I"%)$A`2`Y(```
MD4$`+(%!`P21(0$HD2$!.#D@``!]2D(4D2$!,)$A`6B1(0%`.2```)$A`7"1
M(0%XD2$!B#D@``"100`T@\$"_%7K\`*1(0&`D2$!D($A`"R"@0+8@&$#!('!
M`PQ]7D@0?4I1$(/!`OB!(0`<?H"B%)/!`"A\A$@0?(0A$(/!`NA]2@#0?(0`
MT'R$\A2#P0`DD($`&("!`#2``0`H?2,@$'TI21"`80`4?4H"%(`!`N1]*0#0
MD4$`*(%!`P!\@!@0?(0A$%7C\+Z100`P?5_P$'U*41"#X0+P?&-;>(/!`N"0
M80#<D^$`('R$`-!\92IX?(3R%)"A`;"0@0`0?*Y"%#B```!]2@#0D($!H("!
M`-B0H0`\@`$`('U*`A1\#B@0?``!$("A`-R100`@?_TH%'_<(10Y0```D4$!
MF)/!`:B`H0%@?```T(/!`%B#@0%(?*5Z>(.A`4R3X0&LD*$`7('!`-!@0@``
M@^$`7'U]^!1]7/$45?\H/I/A`-0[@```.Z```#O```"3@0!8@X$!4).A`-B3
MP0#0@Z$!5(/!`+B!X0#4?+-X%'R2<12!X0`P@($#%()!`PB!P0,0?2EZ%'WD
M0A1]!'@0?0A!$)$A`#!4I/"^5*GP`GP`DA2"00#`?(E+>("!`+"0`0`XD2$`
MQ'TC&GA]"`#0?<AR%#D```""80#$?C&8%'X0D12"80&P?G,J>))A`+Q@0@``
M@^$`O'Y]^!1^7/$45+\H/I/A`+0[@```.Z```#O```"3@0"PDZ$`P("A`+23
MP0"X@\$`Z'UK*!1]2B$4@($!7%5J\`)59?"^?*53>'QC6GB!00,8D*$`[)!A
M`%2`80%8?*!*>#T@CQMA*;S<@^$`['^[^!1_FO$4@T$`4(-A`%1_Y-@4?\/1
M%%5[*#Z!80,<DV$`9).!`;"3H0&T@X$`8#A@``!_:5@4?TA1%)!A`&"380%4
M.(```#M@``"300%0@T$!J(.A`&2380!0@V$!K'YSZ!1^4N$4@X$`J)"!`*B`
M@0"85FKP`E9C\+Y\8U-X?`":>)!A`*R0`0"<?&4J>#E```"0H0%(D4$`Z(%!
M`&B#H0"L@*$`G'\YZ!1_&.$4?[LH%'^:(11692@^.T```)"A`&Q@0@``@6$`
M;'__6!1_WE$4@4$#((%A`R0[P```DT$`:(-!`,A^:5@4?DA1%%?D\+Y7ZO`"
M?(13>))!`5B0@0#,?(,:>))A`5PZ0```8$(``(-A`,Q]=]@4?5;1%(+!`RB"
MX0,L?VFX%'](L12100'`@L$`2#E```"380%D@V$!2)%A`<2100"8?WOZ>(%!
M`'"300%@DV$`=#M```"300!PD\$`2)-!`4B!80!T?C%8%'X04117ZR@^D6$`
M3(%A`S0Y0```D4$`R(%!`S""X0!,?[VX%'^<L11^Z5@4?LA1%%>E\`)7JO"^
M?4HK>'QCZGB100#T?4`B>("!`/"2P0&HDN$!K("A`/2080!\.&```(+!`'B"
MX0!\?^<H%'_&(12`H0&P@,$!M#B```"#@0#@D&$`>']FN!1_1;$45[<H/H!A
M`("!80,\DN$`Y)"!`."#H0#D?C'H%'X0X12#@0$(.@```'P`BGA6)O"^D`$`
MA%8G\`)\QSMX?.92>(%!`SB0X0$,?NE8%'[(412!00!`@($`A)+!`;`ZP```
MDN$!M)+!`$!_.2`4?Q@9%%8D*#Z#H0$,@L$`$)"!`$2"X0`4?K7H%'Z4X10[
M@```DX$`@(%A`$1_>U@4?UI1%(%!`T"!80-$.T```'R)6!1\:%$45V7P`E=J
M\+Y]2BMX?,;:>)%!`220@0&\.(```)!A`;B`80$@D($`\'U'.GB`@0$DD,$`
ME("A`<"`P0'$?[<@%'^6&12`80"0@6$#3)-!`!"`@0"4?N8@%'[%&1179"@^
M@*$`B)"!`(PX8```D&$`B(#!`(Q_.3`4?Q@I%#L```!7)O`"5R7POGRE,WA\
MY\IXD*$!/'R@4GB!00-(D.$`_']I6!1_2%$4@4$`&(%A`!R300'`DV$!Q(-!
M`3B#80$\?(O8%'QJT12!00"@.T```)-!`!B080`(D($`#(!A`/B`@0#\?/\@
M%'S>&117)"@^D($`I#O```"3P0"08$(``(%A`*1^]U@4?M91%(%!`U"!80-4
M5N/P`G]I6!1_2%$45NKPOGU*&WB300'(DV$!S)%!`41\`+IX@T$`((-A`"1]
M12IXD`$!%)/!`*"#P0%`@L$!`(%A`UR#X0%$?)OX%'QZ\10[P```@^$`+)/!
M`/B#P0`HD&$!()"!`22`80$0@($!%#M```"300`@?K4@%'Z4&116Y"@^D($!
M!&!"``""X0$$?.>X%'S&L11\I3IX5.3POI"A`2Q4YO`"?(8S>'S#4GB!00-8
MD,$!C'[I6!1^R%$4@4$!B)+!`4"2X0%$@L$!*(+A`2R!80&,?+VX%'R<L114
M]R@^DN$!'']_6!1_7E$4.X```#K```"300$XDV$!/(-!`1B#80$<?K78%'Z4
MT10[8```DV$`*(%!`V"!80-D5J?P`GQCJGB"@0$PD&$!;).!`0!_R5@4?ZA1
M%%:J\+Z#@0`P@6$#;'U*.WB100&DD\$!+#O```"3H0$H@Z$`-)/!`0B#P0&@
M?48R>(/A`:1_??@4?USQ%(.!`6B#H0%LDT$!&)-A`1R#00`(@V$`#'_[Z!1_
MVN$45KTH/I.A`30[0```.V```)-!`#"380$0@T$`V(*A`31\I:@4?(2A%(*!
M`#B"H0`\5*3POE2G\`)\ASMX?,8J>)#A`-Q\Y%)X@4$#:'^I6!1_B%$4DX$!
M,).A`32#80#<?778%'U4T12100%HD6$!;)#!`7R#@0$@@Z$!)(%!`7B"@0%P
M@&$!.(%A`7Q_?5@4?UQ1%%2K*#Z!00&`D6$!=&!"``""H0%T?_^H%'_>H10Z
M@```5_PH/GR$^GB3@0&$D($!E("!`3Q7YO`"@6$!A'][6!1_6E$4@4$!D(%A
M`9179?`"?Z18%'^#412!00%0@6$!5%=D\+Y\A2MXDX$`V)"A`%0[@```DZ$`
MW).!`#B#@0!0@Z$`5'R+Z!1\:N$45WTH/H.!`9B3H0&<D&$`4)"!`%2`80#8
M@($`W(.A`9Q]9.@4?4/A%%?J\+Z`80$8?48S>'S'.GA5:O"^?.?:>)#A`%R`
M@0$<?*<R>(-!`%B#80!<?.=:>(.!`-"0X0"T?^38%'_#T115>R@^@&$!:("!
M`6R380#4@T$`L)#!`,159O`"?4HS>(#!`5A]12IX?5-3>(-A`+2#H0#4?__H
M%'_>X11_I-@4?X/1%(!A`,"`@0#$@T$!8(-A`61\I?IX5^?P`H/!`'"0H0!D
M?>\@%'W.&12`@0!@5^/POGQC.WB`X0%<D&$`='QK4WA\:E`X@*$`9'WO*!1]
MSB$4?*>8%'R&D12"00"X5^<H/H/A`'20X0"\?/OX%'S:\12#00"H@\$`4&!"
M``""80"\?[V8%'^<D117LB@^5[_POI)!`*Q7H/`"?^`#>'^K6#A\'QMX?6I3
M>)%!`.R3X0!8?`,8.(-A`*R#X0!4D`$!3(%!`.B!80#L?>_8%'W.T12"00&H
M@F$!K('!`,A_OU@4?YY1%(/!`4A5ZO`"@^$!3']S^!1_4O$45?\H/H)!`&B#
MP0"8D^$`;&!"``""80!L?[V8%'^<D12"80!8@D$!L'W_F#B"80&T?^,;>)!A
M`)Q5X_"^?&I3>'U#`WA]0``X?Z,8.'U14WA\8`-X5Z/P`I`!`,R#X0"<?*7X
M%'R$\11_\X@4?]*!%((A`'A7LR@^DF$`3('A`,R"80&\?.=X%'S&<12!P0!(
M@>$`3'RE>!1\A'$45Z3POH'A`."!P0#P?(,;>'QD4WA\:E`X?*0@.)!A`/1\
MBE-XD4$`Y%2J\+Y@0@``@@$`Y'][@!1_6GD45+`H/I(!`'Q@0@``@D$`?'SG
MD!1\QHD45*;P`H)!`;B!X0#T?4HS>((A`<1]1AMX?4,8.'SF,#A_LW@4?Y)Q
M%('A`(""00!`?,,;>('!`<B080"$?5E3>%3F\`)4X_"^?&,S>(#!`!"080"D
M@@$`A'__@!1_WGD4@@$!P('A`<Q\L<@4?)#!%%3Q*#Z#`0"(@@$`H)(A`$2"
M(0"D?&=3>'QJ4#B"80!$?WN8%']:D12"80%$@T$`^']G.#A7:_`"?.I3>)%!
M`(Q7:O"^?4I;>'U+&WA]0Q@X?5=3>(,A`(Q_O<@4?YS!%%=Y*#Z3(0`48$(`
M`(#A`!1__S@4?]XQ%'SOB!1\SH$4@B$`D(/!`"!_ZU@X?6,;>%?K\+Z080"4
M5^/P`GUC&WA\:U-X?&I0.()!`)1\I9`4?(2)%()!`4!_,[@4?Q*Q%%?S*#Z"
MP0`8DF$`'&!"``""X0`<?[VX%'^<L11_JU@X?6I3>)%!`/Q7JO"^8$(``(-A
M`/Q\Y]@4?,;1%%>[*#Z380`D8$(``(/A`"2080$,@<$!*('A`2Q\I?@4?(3Q
M%%>D\`*"`0$(@F$!-'U*(WB#00`P?40;>'U#&#A\I"`X?553>'R#&WB"(0$,
M5*3P`I!A`01_[X@4?\Z!%((A`0"!P0`X.@```()!`01_.9`4?QB)%()!`3!_
MLZ@4?Y*A%%2S*#Z"@0`HDF$`+%2E\+XZ0```?*4C>&!"``""H0`L?.>H%'S&
MH11\IE-X@J$!$'RJ4#A\YC`X5./POGS*4W@XP```D4$!%%3J\`)\8U-X.H``
M`'QJ*WA\:R@X@L$!%'__L!1_WJD45/8H/I+!`#0ZP```8$(``(-A`#1_.=@4
M?QC1%'R[*W@[0```5R#POE<D\`)\!"-X5R`H/I`!`#Q_*E`X?4=;>(%!`W"!
M80-T?(`;>'SGZ!1\QN$4.X```'UK2!1]2D$4?6O8%'U*T10[0```@>$`/'__
M>!1_WG$4?)X8.'_@`#A7_2@^?!OS>%?Y\+Z#P0-X5^7P`H/A`WQ\Y^@4?,;A
M%'\E*WA\IB-X?_](%'_>011\H"`X?6O8%'U*T11\?1MX5/LH/GSF,#@[@```
M5./POE3G\`)\8SMX?__H%'_>X12`X0.$?-T#>(#!`X`[0```.X```'UKV!1]
M2M$4?.=(%'S&011\:BMX?__H%'_>X11\8"@X?)LC>'UJ4#@[0```57GPOGSG
MV!1\QM$457TH/GU;`WB!00.(563P`CN```"!80.,?[WX%'^<\10[0```?R0C
M>'SGV!1\QM$4?6M(%'U*011\ORMX?(`;>%>[*#X[P```.T```'UK^!1]2O$4
M?.?8%'S&T12#00.0@V$#E'R<&#A_H``X5[GPOE>E\`)\'^-X?R4K>#O```!_
M>T@4?UI!%'__6!1_WE$4?*8C>'QW&WA4_2@^?*,@.'SF,#@[@```?__H%'_>
MX11_.[@4?QJQ%%3K\+Y\VQMX@,$#F%3J\`*`X0.<.T```'UJ4WA_>\@4?UK!
M%'[I.!1^R#$4?4LK>%?^\+Y7X_`"?\,;>'_K6#B#P0.@5^<H/GR=(WB#X0.D
M.X```#C```!_>S@4?UHQ%'U`*#A\]^@4?-;A%'UY`W@[````?_](%'_>011\
MY\@4?,;!%'RU*WA\95-X?&10.%=S*#Y__Z@4?]ZA%']E*#A7:_`"5V#POGP`
M6WA\YY@4?,:1%'RQ(WB`@0.H@*$#K'__B!1_WH$4?5M3>'P*&WA\!A@X5/TH
M/GSJ4#A4Z_"^?*5(%'R$010[@```5.?P`G__Z!1_WN$4?5DS>(%!`["#@0.X
M?7X[>(%A`[0[0```.P```'REV!1\A-$4?2E8%'T(411\I<@4?(3!%'QW&W@Z
MP```?\,#>'_=`#A7YR@^?2FX%'T(L11_XQ@X.,```'QUZWB#H0.\?*4X%'R$
M,10Z@```5^?P`E?C\+X]8,IB.4```&%KP=9\8SMX?2FH%'T(H11\9/)X5*<H
M/G^]6!1_G%$4.,```'TI.!1]"#$4?)LJ>("!`\!\$P-X5*CP`CI```!4H/"^
M@*$#Q'^]F!1_G)$4.T```'RE6!1\A%$4?`!#>'^]V!1_G-$4?]GS>#L```!\
M"!IX52<H/GRER!1\A,$4.,```'^].!1_G#$4?1]*>($!`\B#@0/052?P`CO`
M``!5.?"^@2$#S'\Y.WA\I?@4?(3Q%'QW&WA7IR@^?R,">'TI6!1]"%$4.,``
M`'RE.!1\A#$4?'OJ>%>G\`(ZP```5Z/POH.A`]1]*;@4?0BQ%#M```!_O5@4
M?YQ1%'QC.WA]*=@4?0C1%'P5`W@Z@```?&3*>%2G*#Y_O:@4?YRA%#C```!]
M*3@4?0@Q%'R?*GB`@0/85*CP`CO```!4H/"^@*$#W'P`0WA_O?@4?YSQ%(/!
M`^B#X0/L?`@:>%4G*#Y\I5@4?(11%#C```!_O3@4?YPQ%'T;2GB!`0/@?S/+
M>%4G\`(Z0```53SPOH$A`^1\I9@4?(21%#M```!]*5@4?0A1%'^<.WA\I=@4
M?(31%'QY&W@[````?X,">%>G*#Y]*<@4?0C!%#C```!\I3@4?(0Q%'QWZGA7
MI_`".L```%>C\+Y\8SMX?2FX%'T(L11\9.)X5*<H/G__6!1_WE$4.,```'TI
M.!1]"#$4?)LJ>("!`_!\%0-X5*CP`CJ```!4H/"^@*$#]'__J!1_WJ$4.T``
M`'RE6!1\A%$4?`!#>'__V!1_WM$4?Y/C>#I```!\"!IX52<H/GREF!1\A)$4
M.,```'__.!1_WC$4?1U*>($!`_B#P00`52?P`CN```!5-_"^@2$#_'[W.WA\
MI>@4?(3A%'QY&WA7YR@^?N,">'TI6!1]"%$4.,```'RE.!1\A#$4?'OZ>%?G
M\`([````5^/POH/A!`1]*<@4?0C!%#M```!__U@4?]Y1%'QC.WA]*=@4?0C1
M%'P5`W@Z@```?&2Z>%2G*#Y__Z@4?]ZA%#C```!]*3@4?0@Q%'R=*GB`@00(
M5*CP`CN```!4H/"^@*$$#'P`0WA__^@4?][A%'P(&GA5)R@^?*58%'R$410X
MP```?_\X%'_>,11]&TIX@0$$$(/!!!A^\[MX52?P`CI```!5-_"^@2$$%'RE
MF!1\A)$4.T```'TI6!1]"%$4?O<[>'REV!1\A-$4?'D;>#L```!^XP)X5^<H
M/GTIR!1]",$4.,```'RE.!1\A#$4?'WZ>%?G\`([@```5^/POH/A!!R"#``$
M?&,[>'TIZ!1]".$4@>P``((L``Q\9+IX5*<H/G__6!1_WE$4.,```'TI.!1]
M"#$4?)LJ>("!!"!\%0-X5*CP`CJ```!4H/"^@*$$)'__J!1_WJ$4.T```'RE
M6!1\A%$4?`!#>'__V!1_WM$4?O.[>#I```!\"!IX52<H/GREF!1\A)$4.,``
M`'__.!1_WC$4?1U*>($!!"B#P00P52?P`CN```!5-_"^@2$$+'[W.WA\I>@4
M?(3A%'QY&WA7YR@^?N,">'TI6!1]"%$4.,```'RE.!1\A#$4?'OZ>%?G\`([
M````5^/POH/A!#1]*<@4?0C!%#M```!__U@4?]Y1%'QC.WA]*=@4?0C1%'P5
M`W@Z@```?&2Z>%2G*#Y__Z@4?]ZA%#C```!]*3@4?0@Q%'R=*GB`@00X5*CP
M`CN```!4H/"^@*$$/'P`0WA__^@4?][A%'P(&GA5)R@^?*58%'R$410XP```
M?_\X%'_>,11]&TIX@0$$0(/!!$A^\[MX52?P`CI```!5-_"^@2$$1'REF!1\
MA)$4@DP`%#M```"";``<?2E8%'T(411^]SMX?*78%'R$T11\>1MX.P```'[C
M`GA7YR@^.,```'TIR!1]",$4?*4X%'R$,11\??IX5^?P`CN```!7X_"^@^$$
M3'QC.WA]*>@4?0CA%%2G*#Y\9+IX?_]8%'_>410XP```?2DX%'T(,11\%0-X
M?)LJ>("!!%!4H/"^.H```%2H\`*`H014?_^H%'_>H12"C``D.T```'UK*!1]
M2B$4?`A#>'__V!1_WM$4?N>[>#C```!5)"@^?6LX%'U*,11]!1IX?O\B%'RG
M2G@ZP```.,```%;E*#Y\YU@4?,91%%;**#15(/"^52;P`GRI4WA]9TH4.4``
M`'UK@!1]2GD4@@P`"#N```!\'3-X?O>(%'[6@12"+``0.\```'T?0WA_O9`4
M?YR)%(),`!@X@```?&4;>'__F!1_WI$4@FP`(#D@``"1+```?*6@%'R$F121
M;``$D2P`")+L``R1+``0DZP`%)$L`!B3[``<D2P`()"L`"2"@01<@J*/^'Z4
MJGDZH```0((`7(`!!+2!P01H@>$$;((!!'!\"`.F@B$$=()!!'B"801\@H$$
M@(*A!(2"P02(@N$$C(,!!)"#(024@T$$F(-A!)R#@02@@Z$$I(/!!*B#X02L
M."$$L$Z``"!(`">E+`,``$&"`3"4(?_0/2`0`GP(`J:380`<@VFQ()`!`#23
M00`8+YL``).!`""3H0`DD\$`*)/A`"Q!G@"(B2,``"^)``!!G@#H*XD`/3O`
M``!!G@`@?'X;>(T^``$O"0``*XD`/4&:``A`GO_P?\/P4(/[```OGP``09X`
M2'R:(WA\?!MX?WW;>&````!@````?^/[>'^$XWA_Q?-X2``J%2^#``!`G@`0
M?3_PKB^)`#U!G@!`A_T`!"^?``!`GO_4@`$`-(-!`!@X8```@V$`'(.!`"!\
M"`.F@Z$`)(/!`"B#X0`L."$`,$Z``"!@````?[OH4#A^``%_O19P?'\:%).Z
M``"``0`T@T$`&(-A`!R#@0`@?`@#IH.A`"2#P0`H@^$`+#@A`#!.@``@.\``
M`$O__T`X8```3H``(&````"4(?_0?`@"II/!`"B3X0`LD`$`-'Q_&W@_P!`"
M@2*/^)$A`!PY(```?^/[>#B!`!A,QC&"2__^C2^#``!!G@!,@4$`&($>L2!5
M2A`Z?2A2%(3I``0OAP``?.A1+D&>_\R%20`$+XH``)%)__Q`GO_T?^/[>#B!
M`!A,QC&"2__^12^#``!`GO^\@4$`'($BC_A]2DIY.2```$""`!R``0`T@\$`
M*(/A`"PX(0`P?`@#IDZ``"!(`"6M8````&````"4(?_`?`@"II.!`#"0`0!$
MDZ$`-)/!`#B3X0`\DP$`(),A`"2300`HDV$`+'Q_&WB))```:3T`/2.]``!_
MI`&4@2*/^)$A`!PY(```?Z/K>$@`)K$X@0`8?'P;>'_C^WA,QC&"2__]G7Q^
M&WE!@@%T2``FD7^<&$!`G0$X@V$`&#]`$`)7>Q`ZB3\``"^)``!!G@($*XD`
M/4&>`?Q_ZOMX2```&&````!@````8````"N)`#U!G@`0C2H``2^)``!`GO_P
M?5]04#A\``*#VK$@?&-2%$@`);TO@P``?'[9+D&>`<B)/P``@4$`&($:L2!5
M2A`Z+XD``'U(4"Z9*@``09X`."N)`#U!G@`P?^C[>$@``!A@````8````&``
M```KB0`]09X`%(TH``&=*@`!+XD``$">_^PY(``].'W__YDJ``!@````8```
M`&````"-(P`!G2H``2^)``!`GO_T.&```(%!`!R!(H_X?4I*>3D@``!`@@$\
M@`$`1(,!`""#(0`D@T$`*'P(`Z:#80`L@X$`,(.A`#2#P0`X@^$`/#@A`$!.
M@``@8````&`````X??__.5[__V````!@````C2,``9TJ``$OB0``0)[_]$O_
M_Y!@````8````&`````_0!`"@QJQ(($X```OB0``09X`K'\*PW@[P```8```
M`(4J``0[W@`!+XD``$">__0XG@`"5(00.CU`$`*!*K%$+XD``$&>`#Q_`\-X
M2``D52^#``"0>K$@09X`<%?;$#HY/@`!.4```%4I$#I]0TDND\$`&$O__C1@
M````8````#D@``%\@R-XD2JQ1$@`)"5\>1MY08(`-%?;$#I_!,-X?V7;>$@`
M(IV3.K$@?R/+>$O__[`Y0```2__^,#B```@[P```2___=#A@__]+__ZX2``B
M\6````!@````8````)0A_V!\"`*FDZ$`E)`!`*2380",DX$`D)/!`)B3X0"<
M?'T;>8$BC_B1(0!\.2```$&"`!")/0``+XD``$">`$2!00!\@2*/^'U*2GDY
M(```0((!2(`!`*2#80",@X$`D(.A`)1\"`.F@\$`F(/A`)PX(0"@3H``(&``
M``!@````2``ET7Q^&WE!@O^X/V`0`#M[:^A_P_-X2``E.2P#``!!@@"@B2,`
M$R^)`"Y!G@"T.^,`$W^CZWA(`".)?'P;>'_C^WA(`"-]?'P:%#AC``)(`",!
M.(```3B@__]_9MMX?Z?K>'Q\&WA_Z/MX3,8Q@D@`(Y$X8``#?X3C>#BA`!!(
M`"4!+X/__W^#XWA!G@`4@2$`(%4I!"8KB4``09X`=$@`(>%_@^-X2``A27_#
M\WA(`"2A+`,``$""_VQ@````?\/S>$@`)/U_H^MX2``A94O__O!@````8```
M`&````")(P`4+XD``$&>_RPKB0`N0)[_0(DC`!4OB0``09[_&$O__S!@````
M8````&````!+__YQ2___D$@`(4E@````E"'_X'P(`J:3X0`</^`0`H!_L2B0
M`0`DDZ$`%)/!`!A(`"11@2,`@(!_L2B#J0`$2``D08DC`&6`?[$H53X&?D@`
M)#&!(P`$@2D`$%4IA#!_R4MXL3T``H!_L2A(`"05@2,`@(!_L2B#R0`$2``D
M!3R`$``XH```.(1N^$@`(E60?@`<@'^Q*$@`(^F!(P"`@'^Q*(/)``1(`"/9
M@2,%N(!_L2B1/@`@2``CR8$C`("`?[$H@\D`!$@`([DY0```@2,`_"^)``!!
MG@`4@'^Q*$@`(Z&!(P#\@4D`<)%>`"2`?[$H.\```$@`(XF!(P"`@'^Q*($I
M``23R0`H2``C=8$C`("`?[$H@2D`!)/)`!A(`"-A@2,`@(!_L2B#Z0`$2``C
M48$C`AB1/P`L@`$`)(.A`!2#P0`8@^$`'#@A`"!\"`.F3H``(&````!@````
ME"'_X'P(`J:3X0`</^`0`I/!`!A\?AMX@'^Q*)`!`"1(`",!?\3S>#BC`0@X
M8``#2``C`2^#``!!G@`H@`$`)(/!`!@X8```@^$`'#@A`"!\"`.F3H``(&``
M``!@````@'^Q*$@`(KV!(P$852D$)BN)0`!!G@`@@'^Q*$@`(J6!(P$852D$
M)FTJ__\OBJ``0)[_K'_#\W@X@``"2``AY8`!`"2#P0`8@^$`'#@A`"!\"`.F
M?&,`-%1CV7Y.@``@E"'OT#B@#_]\"`*FDZ$0))/!$"B0`1`TD^$0+'Q^&W@\
M8!``?)TC>#AC:_`X@0`<@2*/^)$A$!PY(```2``?12P#``!`@0"<.^/__SE!
M$"!]*OH4B2GO_"^)``!!G@!T?'\;>#AA`!PX@``O?^7[>$@`(.$O@P``09X`
M:#T@$`*`:;$H2``AW7_$\W@XH0`<?^;[>$@`(6V!(1`<@4*/^'TI4GDY0```
M0((`5(`!$#2#H1`D@\$0*(/A$"PX(1`P?`@#IDZ``"!@````8````"^?``!`
MGO^08````&`````](!`"@&FQ*$@`(7E_Q/-X?Z7K>$@`'IU+__^@2``>-90A
M__`](!`"?`@"IH!IL2B0`0`42``A38`!`!0\@!``/*`0`#S`$`!\"`.F.(1L
M`#BE9@`XQFM4."$`$$@`'[24(?_@?`@"II/A`!P_X!`"@'^Q*)`!`"1(`"$)
M2___I8!_L2A(`"#]@`$`)#S`$`"#X0`</(`0`#R@$``XQF[X?`@#ICB$;!PX
MI5Z0?,<S>#D````X(0`@2``@&&````"4(=_0?`@"II/!("B0`2`TD^$@+($B
MC_B1(2`<.2```$@`'C$\P!``/0`0`'QG&W@X@``!.&$`%#B@$`$XQFPT.0AL
M0$S&,8)(`![I+X,``$&<`'`X80`4.($0&#B@$`!(`!V!?'X;>4&``%@X?@`!
M2``>$7Q_&WE!@@!(.($0&'_%\WA(`!RM.2```'_C^WA]/_&N@4$@'($BC_A]
M2DIY.2```$""`"2``2`T@\$@*(/A("PX(2`P?`@#IDZ``"`X8```2___T$@`
M',E@````E"'_\#@A`!!+__\H8````)0A[[!]@``F?`@"II-A$#R3H1!$D`$0
M5)/A$$R1@1`@DJ$0))+!$"B2X1`LDP$0,),A$#2301`XDX$00)/!$$A\?1MX
M/&`0`'R?(W@X8VQ(.($`&($BC_B1(1`<.2```$S&,8)+__2M.(``+WQ[&WA_
MH^MX2``=?2^#``!!G@!T/&`0`'^DZW@X8VQ43,8Q@DO_]H%_H^MX@4$0'($B
MC_A]2DIY.2```$""`;2``1!4@8$0((*A$"2"P1`H?`@#IH+A$"R#`1`P?8"!
M((,A$#2#01`X@V$0/(.!$$"#H1!$@\$02(/A$$PX(1!03H``('^CZW@_@!``
M2``=&3N<;&0N&P``?X3C>'QY&WA_X_MX2``>07Q^&WE!@O]H/N`0`#\`$``Z
MH```/L`0`#LY``$Z]VQH.QAL<#]`$`)BM8``.^```&````!@````8````(D^
M```OB0``0)X`"#O6;$1!D@`8?V/;>'_$\WA(`!J5+X,``$&>`)Q_P_-X2``<
ME7R^&A2))?__+XD`+T">`!B?Y?__.&/__XE%__\OB@`O09[_\'UY&A0OBP__
M09W^U#B```$XH!``?N:[>'_'\WA_",-X?ZGK>#AA`!Q,QC&"2``<@8!ZL2A(
M`!X).($`'#BC`0@X8``#2``=Z2^#``!`G@`<@'JQ*$@`'>F!(P$852D$)G^)
MJ`!!G@`@.&```'^$XWA(`!T]+X,``'Q^&WA`GO\P2__^7#AA`!PX@``!2``=
M$2^#``!`GO_4/&`0`#B!`!PX8VQ43,8Q@DO_],4X80`<2``<34O__D!(`!I5
ME"'_\(DC```OB0``09X`0#E#``%(```<8````&````")*@``.4H``2^)``!!
MG@`@*XD`+T">_^R)*@``?4-3>#E*``$OB0``0)[_Z#@A`!!.@``@8````&``
M``!@````E"'_X'P(`J:3X0`<?'\;>9`!`"23P0`808(`^(O?```OG@``09X`
M[$@`&RDX8___?+\:%'^?*$!`G``\?3\8KB^)`"]`G@$<?3\H4'TI`Z9(```<
M8````&````!@````B24``"^)`"]`G@#X.*7__T(`__!_GRA`09X`B#DE__]_
MGTA`?3\H4'TI`Z9!G0$L+Y___T"^`!A(``$@8````(DE```OB0`O0)X`##BE
M__]"`/_P?+\H4#DE``(KB1``09T`@#Q@$`)_Y/MX.&.Q1#BE``$[PP`$.,`0
M`'_#\WA(`!MA@`$`)'_#\WB#X0`<@\$`&#@A`"!\"`.F3H``("N>`"]`G@"4
M8````&`````X8``"2``9S2P#``!!@@`D.2`N`+$C``"``0`D@\$`&(/A`!PX
M(0`@?`@#IDZ``""``0`D@\$`&#A@``"#X0`<."$`('P(`Z9.@``@8````#DE
M__]_GTA`?3\H4'TI`Z9!G0!4+Y___T"^`!1(``!(B24``"^)`"]!GO[T.*7_
M_T(`__!+__[@@`$`)(/!`!@\8!``@^$`'#AC;'!\"`.F."$`($@`&BPY(``!
M?2D#IDO__NPY(``!?2D#IDO__\"4(?^P/(`0`'P(`J8XA&M4.*``(CB$``R0
M`0!4DX$`0).A`$23P0!(D^$`3#AA`!@_X!``/\`0`#O_;)P[WFQ(/X`0`#^@
M$``[G&RX.[ULQ($BC_B1(0`\.2```$@`%V4\8!``.&-L=$S&,8)+__%5/&`0
M`#AC;(!,QC&"2__Q13Q@$``X8VR(3,8Q@DO_\34\8!``.&-LE$S&,8)+__$E
M?^/[>$S&,8)+__$9/&`0`#AC;*Q,QC&"2__Q"7_#\WA,QC&"2__P_7^#XWA,
MQC&"2__P\7^CZWA,QC&"2__PY3Q@$``X8VS03,8Q@DO_\-4\8!``.&-L5$S&
M,8)+__#%/&`0`#AC;-Q,QC&"2__PM3Q@$``X8VSH3,8Q@DO_\*4\8!``.($`
M%#AC;/1,QC&"2__O47QD&WE!@@`0?Z/K>$S&,8)+__$]/&`0`#B!`!0X8VT(
M3,8Q@DO_[RE\9!MY08(`%#Q@$``X8VT<3,8Q@DO_\1$\8!``.($`%#AC;2A,
MQC&"2__N_7QD&WE!@@!D?\/S>$S&,8)+__#I/(`0`'_C^W@XA&U83,8Q@DO_
M\-6!00`\@2*/^'U*2GDY(```0((`D(`!`%2#@0!`@Z$`1(/!`$A\"`.F@^$`
M3#@A`%!.@``@8````&````!@````/&`0`#B!`!0X8VTX3,8Q@DO_[H%\9!MY
M08(`&'^#XWA,QC&"2__P;4O__X1@````/(`0`#AA`"DXA&U,.*``"D@`&0$O
M@P``0)[_9'^#XW@X@0`S3,8Q@DO_\#E+__]02``5T6````!@````8````)0A
M_]!\"`*FD^$`+)`!`#0_X!`"@'^Q&"^#__^!(H_XD2$`'#D@``!!G@`X@4$`
M'($BC_A]2DIY.2```$""`'"``0`T@^$`+#@A`#!\"`.F3H``(&````!@````
M8````#Q@$``X@0`8.&-LN$S&,8)+_^VQ+`,``$&"`"B)(P``.&```"^)``!!
MG@`0:2,`,'QC`-!48P_^D'^Q&$O__Y`X8```D'^Q&$O__X1(`!45E"'_\'P(
M`J:0`0`42``5%4@`%'$L`P``08(`&(!C``"``0`4."$`$'P(`Z9.@``@.&``
M`$O__^Q@````8````)0A_Z`](!``?`@"ICDI:U2!20`P@(D`-("I`#B`R0`\
M@.D`0($)`$23P0!8D^$`7)`!`&23(0!$DT$`2)-A`$R3@0!0DZ$`5($I`$A]
M7U-Y.\$`((%BC_B180`\.6```)%!`""0@0`DD*$`*)#!`"R0X0`PD0$`-)$A
M`#A!@@"`/,`0`#T`$`!\?!MX.T9L:#MH;&1(```H8````&````!_A.-X2``3
M;2^#``!!G@"4A_X`!"^?``!!G@!$?^/[>#B!`!Q,QC&"2__L:7Q]&WE!@@`0
MB5T``"^*``!`GO_$?^/[>'^$XWA,QC&"2__N18?^``0OGP``0)[_Q($A`#R!
M0H_X?2E2>3E```!`@@",@`$`9(,A`$2#00!(@V$`3'P(`Z:#@0!0@Z$`5(/!
M`%B#X0!<."$`8$Z``"!@````?X/C>$@`%.U\>1MX?Z/K>$@`%.%\>1H4.&,`
M`D@`%&4X@``!.*#__W]&TWA_A^-X?'D;>']HVWA_J>MX3,8Q@D@`%/%_X_MX
M?R3+>$S&,8)+_^VA2___'$@`$SE@````/`#__WPL"WA@`'ZP/2`0`'PA`6Y\
M"`*F.2EK5(%I`&"`J0!D@,D`:(#I`&R!"0!P@4D`=)`,``2`"0!<DHS_T)+,
M_]B2[/_<DPS_X),L_^23S/_XD^S__)(,_\"2+/_$DDS_R))L_\R2K/_4DTS_
MZ)-L_^R3C/_PDZS_]#_`$`"#Z0!8@LD`3'QX&WB"Z0!0@RD`5#O>;$@X@0`4
M@2D`>'_#\W@^@0`!@J*/^)*T@0PZH```D^$`,)+!`!B2X0`<DR$`()`!`#21
M80`XD*$`/)#!`$"0X0!$D0$`))%!`"B1(0`L3,8Q@DO_ZJE\?QMY08(`$(D_
M```OB0``0)X%!$O__2$[X0`@.R$`%'QW&WE!@@)\?N.[>$@`$WE48P@\.&,`
M`4@`$OV(]P``+X<``'QY&WA!G@!$/L`0`'Q_&W@ZUFUD8````&````!@````
M?^/[>#B```$XH/__?L:S>$S&,8)(`!-MC/<``3O_``(OAP``0)[_W#OA@1`Z
MP0`4A']_("^#``!`G@`42```5(1_``0O@P``09X`2'[$LWA,QC&"2__I[7QW
M&WE!@O_DB3<``"^)``!!GO_82__QA2^#``!!GO_,?N.[>$@`$U5\=AMY0((`
M@&````!@````@^$`&"^?``!!G@'8B3\``#K@``$OB0``0)X`/$@``<0Y0```
M5ND0.F%*@1!]2@H4?2I*%#TI__^#Z7\(+Y\``$&>`:")/P``.O<``2^)``!!
MG@&0?^/[>$O_\0DO@P``09[_P'_C^WA(`!+9?'8;>4&"_[!^P[-X/H`0`$@`
M$C4ZE&QP?'\;>'\CRWA(`!(E?'\:%#OC!`1_X_MX2``1I3S`$``](!``.(``
M`3B@__]\=1MX.,9M;'['LWA^B*-X.2EM>'\JRWA,QC&"2``2)7ZCJW@X@`'`
M2``262^#__]!G@$0/R`0`H!YL2A(`!.5?J2K>#BC`0@X8``#2``3E2^#``!!
MG@$L/2`0`H#8```\H!``@&FQ)#B```$XI6X`?J>K>$S&,8)(`!*9.&```#Z!
M``&"M($,@H*/^'ZUHGDZ@```0(((5(%A``"`"P`$@@O_P((K_\2"2__(?`@#
MIH)K_\R"B__0@JO_U(++_]B"Z__<@PO_X(,K_^2#2__H@VO_[(.+__"#J__T
M@\O_^(/K__Q]85MX3H``(&````!(`!&A?'<;>4""_8R$?P`$+X,``$&>`GQ_
M),MX3,8Q@DO_Y_%\:1MY08+_Y(DI```OB0``09[_V$O__\A@````.L```$O_
M_I!@````8````$@`$7&!`P``+X@`$4&>_N@](!`"@-@``#R@$`"`:;$D.(``
M`3BE;8!^IZMX3,8Q@D@`$:$X8```2___"&````"`>;$H2``238$C`1A5*00F
M*XE``$">_L2`>;$H2``2-8+C`2!(``\-?Y<8`$">_JR`>;$H2``2'8$C`1A5
M*07^*XD!P$">_I1_X_MX2``/Q3B!`!1\=QMX/&`0`#AC;TQ,QC&"2__G'2^#
M``!!G@;T@_@``$@`$)U\9!MX?^/[>$O_\?%\>1MY08(&V'\CRWA(``_Q+X,`
M`WQ_&WA`G0!$.&/__#R`$`!\>1H4.(1MO$@`#<$O@P``0)X`*"^?``1!G@6D
M?_GZ%(D___LOB0`O09X%E&````!@````8````$O_^($O@P``0)X`''\CRW@X
M@```3,8Q@D@`#ZE\<AMY0((!$#R`$``\8!``.(1M6#AC;+A,QC&"2__H:4@`
M#L4_H!``/,`0`#N];O@X@``!?&D;>#B@__]^X[MX.,9MW'ZGJWA^B*-X?ZKK
M>#^`$`!,QC&"2``/;3O@```[G&WL2```5&````!@````8````$@`#\&!(P``
M+XD`$4">`$Q(``YADZ$`"#O_``$X@``!.*#__WQI&WA_AN-X?N.[>'ZGJWA^
MB*-X?^K[>$S&,8)(``\1?N.[>#B``<!(``]%+X/__T&>_ZQ^HZMX2``,Y7[D
MNWA_P_-X3,8Q@DO_YZ5^X[MX2__X;7[CNWA+__T42__X87_C^WA(``\92__]
M!#[@$``X8``-.O=M7$O_^P@XH/__.,#_[CC@``)(``VU?D.3>#B!`0PXH``&
M2``,58DA`0POB0``0)X`$(DA`0TOB0!#09X$E'Y#DW@XH```.,```#C@``!(
M``UY/2!G13D```!A*2,!D0$`2)$A`$P](._-82FKB3D```"1(0!4/2"8NF$I
MW/Z1`0!0D2$`7#T@$#)A*51V.0```)$A`&0](,/282GA\)$!`%@Y````.4``
M`#E@``"1`0!@D2$`;#D````Y(```D0$`:)%!`'"180!TD4$`>)%A`'R1(0#`
M.B```#K!`(`Z80!(8````#B@``!^0Y-X.($!#&"E@`!(``N!?'@;>4"!`6"!
M00!P?P?^<%<)'WZ!80!T5/P8.%<=&#@KB@``?3SC>'T]6!1]'%$409T#'"^*
M``!`G@`,?XM(0$&=`PR!00!X@6$`?(!A`,!4Z!@X5QL??GT;VWA4^A]^+X,`
M`'UKV!1]2M$4DB$`<)$A`'2100!XD6$`?$&>`L`A(P!`?Q##>'^82`!`G0`(
M?3!+>'QS&A0X@0$,.&,`.'X%@WA(``L9@2$`P'TP2A0OB0!`D2$`P$">_S0X
M@0$,?F.;>'\0P%!^!((42_^\L6````!@````8````"^8`#]`G0!0?QG#>'X?
M@WA_Y/MX.*``0'[#LW@[.?_`2``*P7YCFW@[_P!`2_^\=2^9`#]!G?_<.QC_
MP%<)T;X=2?_`.2D``54I,#)^$$H4?QA2%'\%PWA^!(-X.,``2'[#LWA(``OM
M.*```'Y#DW@X@0$,8*6``),!`,!(``HE?'@;>4&!_JA^0Y-X2``.!8/A`'0Y
M08$0@Z$`?%?E[KXY)0`!+XD`.'TJ*A0Y0/^`F4E_<$&=`A`Y08$0.(```'QJ
M*A0@I0`W.&-_<4@`#$57I48^5Z:$/E>GPCY7Z$8^5^J$/E?IPCXX80!(F*$`
MN)C!`+F8X0"ZFZ$`NYD!`+R900"]F2$`OIOA`+]+_[N5@,$`5("A`$R!`0!<
M@4$`9($A`&Q4UD8^5*=&/E4<PCY5748^55^$/E2RA#Y4L\(^5-B$/E39PCY5
M&D8^51N$/E5`PCY5*T8^52.$/E4DPCZ:P0#0/L`0`)N!`-:;H0#8F^$`V9CA
M`,R:00#-FF$`SIBA`,^;`0#1FR$`TIC!`-.;00#4FV$`U9D!`->8`0#:F4$`
MVYEA`-R880#=F($`WIDA`-\[X0#@.Z$`S#N!`0@ZUFUD2```$&````!@````
MC/T``7_C^W@X@``!.*#__W[&LW@[_P`"3,8Q@D@`"O5_G^!`0)[_W#S`$``]
M0!``.6```#B@__\XQFW,?J>K>'Z(HW@Y(0#@.4IN^#B```%^X[MXF6$!"$S&
M,8)(``JU?J.K>$@`")U^Y+MX?\/S>$S&,8)+_^-=?N.[>$O_]"5^X[MX2__X
MS&````!@````.@$!#$O__9Q@````8````(%!`'B!80!\,6L``7U*`91+__SP
M@_@`!"^?``!!GOIT?^/[>$@`"@TK@P`#0)WZ9#AC__P\@!``?'\:%#B$;<1(
M``?A+X,``$">^DA_^?MX2__Z0#B!`$A\9"H4(*4`/SB````X8P`Y2``*.3AA
M`$A+_[G!.&$`@#B````XH``X2``*(4O__=R)(0$.+XD`04">^VB)(0$/+XD`
M0T">^UR)(0$0+XD`2$">^U")(0$1+XD`14">^T0XP/_&..```CB@__]^0Y-X
M2``(N3B!`0Q^0Y-X.*``*4@`!UD\P!``/4`0`'[CNW@X@``!.*#__SC&;<Q^
MIZMX?HBC>#DA`0PY2F[X3,8Q@D@`"6E+__IL@S@``$O_^2A(``>Y8````)0A
M_[!\"`*FDR$`-)`!`%22X0`LDP$`,)-!`#B380`\DX$`0).A`$23P0!(D^$`
M3#\@$`*`>;$H@2*/^)$A`!PY(```2``*G3D@``$X@0`8F2,`83Q@$``X8VR<
M3,8Q@DO_W[$L`P``08(`$(DC```OB0`Q09X";$O_[QF`>;$H/Z`0`CN]L41(
M``I9/(`0`#B@``$XA&Y4.,``"T@`"!4L`P``08(`X($]$`2!0P`0+XD``8-*
M`!A`G0#,/V`0`C\``"`[P```.^```3M[L2AC&`0`2```-&````!@````@(@`
M$'[CNWA(``89@3T0!"^#``!`G@"$._\``3O>``%_B?@`0)T`=(![``!(``G5
M?T33>'_%\W@XP```2``)17Q\&WE!@@(<@1P``(#]$`A7ZA`Z@2@`"'[G4"Y_
M"4@X*XD$`$&>_YR`>P``2``)E8"<```XH```.,```D@`!L5\9!MX?N.[>$@`
M!9F!/1`$+X,``$&>_X0Y2?__?XKP`$&>`7"`>;$H/\`0`D@`"54\@!``.*``
M`3B$;EPXP``#2``'$7Q_&WE!@@`T@'ZQ*$@`"3&!/P`0/*`0`#BE;F"`B0``
M2``&38$_`!"!*0``@2D`"'4J`$!`@@)\@'FQ*#_@$`)(``C]/(`0`#B@``$X
MA&YH.,```T@`!KE\?AMY08(`.#Q@$``X@0`8.&-L5$S&,8)+_]W]?'P;>8!_
ML2A!@@'02``(O8$^`!!_A>-X@(D``$@`!=V`>;$H2``(I3D@```X@0`8F2,`
M83Q@$``X8VQ(3,8Q@DO_W;DO@P``?'\;>)!]$`Q!G@#X.(`!P$@`!R$O@P`1
M?&8;>$&>`!`Y(P`!*XD``4&=`?B!(0`<@4*/^'TI4GDY0```0((!X(`!`%2"
MX0`L@P$`,(,A`#1\"`.F@T$`.(-A`#R#@0!`@Z$`1(/!`$B#X0!,."$`4$Z`
M`"!@````8````&````")(P`!+XD``$&>_91+__V,+XD``4"=_I`[X``!2```
M%&````!@````8````&````"`>P``._\``4@`!\E_1--X2``$08$]$`1_B?@`
M09W_Y$O__E1@````8````&````"!/1`$.4G__W^*\`!`GOXX2___H&````!@
M````8````(!]$`A+__$=+X,``)!]$`Q!G@#\@3X`$#T``"!A"`0`@4D``($J
M``A]"4@X*XD$`$">`*"`:@`0@_T0"'_D^WA(``11@3X`$#T``""#_P``80@$
M`(%)``!\?1MX@2H`"'T)2#@KB00`0)X`1("J`!`\8!``?^3[>#AC;I!_INMX
M3,8Q@D@`!7U@````8````$@`!O&!7@`0@3T0"(!J``"`B0``2__D?4O__C"`
M>;$H2``&T8$^`!`XH```.,```H")``!(``/]?&4;>$O__Z0](!`"@&FQ*$@`
M!JF!/@`0.*```#C```*`B0``2``#U4O__TB`?K$H2``&B8$_`!"`B0``2``%
MC4O__70\8!``.&-N;$S&,8)(``3I2``#-8$]$`@\8!``?^7[>#AC;KB`B0``
M3,8Q@D@`!,E@````E"'_X'P(`J:3P0`8D^$`')`!`"1\?AMX2__I"8DC``!\
M?QMX+XD``$&>`$0Y0P`!2```(&````!@````8````(DJ```Y2@`!+XD``$&>
M`"`KB0`O0)[_[(DJ``!]7U-X.4H``2^)``!`GO_H2__LY2^#``!!G@`P+YX`
M`$&>`"B)/@``+XD``$&>`!P\@!``?^/[>#B$;7A(``&Y?Y\8`$&>`!R``0`D
M@\$`&(/A`!PX(0`@?`@#IDZ``""``0`D@^$`''_#\WB#P0`8."$`('P(`Z9+
M_]]<8````&````"4(?_@?`@"II/A`!P_X!`"@'^Q*)`!`"1(``5).(#__T@`
M`J&`?[$H2``%.8`!`"2#X0`</(`0`#B$10`XH```?`@#IC@A`"!(``3H````
M`)0A__!\"`*F0I\`!9/!``B0`0`4?\@"IC_>``([WLIX@3Z``"^)``!!G@`@
M@,D``$@``E&``0`4@\$`"#@A`!!\"`.F3H``(#C```!+___DE"'_T'P(`J9"
MGP`%D\$`*),A`!1_R`*FDT$`&)-A`!R3@0`@DZ$`))/A`"R0`0`T?'D;>'R:
M(WA\NRMX/]X``CO@```[WLHL2_^NA8$^@`2#GH``?XG@4#NI__Q_G!9Q08(`
M-&````!@````8````(4]``1_(\MX?T33>']EVWA]*0.F._\``4Z`!"%_G^!`
M0)[_X(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H@^$`+#@A`#!.
M@``@3H``(````````````````#U@$`*!:[``?6D#IDZ`!"`]8!`"@6NP!'UI
M`Z9.@`0@/6`0`H%KL`A]:0.F3H`$(#U@$`*!:[`,?6D#IDZ`!"`]8!`"@6NP
M$'UI`Z9.@`0@/6`0`H%KL!1]:0.F3H`$(#U@$`*!:[`8?6D#IDZ`!"`]8!`"
M@6NP''UI`Z9.@`0@/6`0`H%KL"!]:0.F3H`$(#U@$`*!:[`D?6D#IDZ`!"`]
M8!`"@6NP*'UI`Z9.@`0@/6`0`H%KL"Q]:0.F3H`$(#U@$`*!:[`P?6D#IDZ`
M!"`]8!`"@6NP-'UI`Z9.@`0@/6`0`H%KL#A]:0.F3H`$(#U@$`*!:[`\?6D#
MIDZ`!"`]8!`"@6NP0'UI`Z9.@`0@/6`0`H%KL$1]:0.F3H`$(#U@$`*!:[!(
M?6D#IDZ`!"`]8!`"@6NP3'UI`Z9.@`0@/6`0`H%KL%!]:0.F3H`$(#U@$`*!
M:[!4?6D#IDZ`!"`]8!`"@6NP6'UI`Z9.@`0@/6`0`H%KL%Q]:0.F3H`$(#U@
M$`*!:[!@?6D#IDZ`!"`]8!`"@6NP9'UI`Z9.@`0@/6`0`H%KL&A]:0.F3H`$
M(#U@$`*!:[!L?6D#IDZ`!"`]8!`"@6NP<'UI`Z9.@`0@/6`0`H%KL'1]:0.F
M3H`$(#U@$`*!:[!X?6D#IDZ`!"`]8!`"@6NP?'UI`Z9.@`0@/6`0`H%KL(!]
M:0.F3H`$(#U@$`*!:["$?6D#IDZ`!"`]8!`"@6NPB'UI`Z9.@`0@/6`0`H%K
ML(Q]:0.F3H`$(#U@$`*!:["0?6D#IDZ`!"`]8!`"@6NPE'UI`Z9.@`0@/6`0
M`H%KL)A]:0.F3H`$(#U@$`*!:["<?6D#IDZ`!"`]8!`"@6NPH'UI`Z9.@`0@
M/6`0`H%KL*1]:0.F3H`$(#U@$`*!:["H?6D#IDZ`!"`]8!`"@6NPK'UI`Z9.
M@`0@/6`0`H%KL+!]:0.F3H`$(#U@$`*!:["T?6D#IDZ`!"`]8!`"@6NPN'UI
M`Z9.@`0@/6`0`H%KL+Q]:0.F3H`$(#U@$`*!:[#`?6D#IDZ`!"`]8!`"@6NP
MQ'UI`Z9.@`0@/6`0`H%KL,A]:0.F3H`$(#U@$`*!:[#,?6D#IDZ`!"`]8!`"
M@6NPT'UI`Z9.@`0@/6`0`H%KL-1]:0.F3H`$(#U@$`*!:[#8?6D#IDZ`!"`]
M8!`"@6NPW'UI`Z9.@`0@/6`0`H%KL.!]:0.F3H`$(#U@$`*!:[#D?6D#IDZ`
M!"`]8!`"@6NPZ'UI`Z9.@`0@/6`0`H%KL.Q]:0.F3H`$(#U@$`*!:[#P?6D#
MIDZ`!"`]8!`"@6NP]'UI`Z9.@`0@/6`0`H%KL/A]:0.F3H`$(#U@$`*!:[#\
M?6D#IDZ`!"`]8!`"@6NQ`'UI`Z9.@`0@/6`0`H%KL01]:0.F3H`$(#U@$`*!
M:[$(?6D#IDZ`!"`]8!`"@6NQ#'UI`Z9.@`0@2``!$$@``0Q(``$(2``!!$@`
M`0!(``#\2```^$@``/1(``#P2```[$@``.A(``#D2```X$@``-Q(``#82```
MU$@``-!(``#,2```R$@``,1(``#`2```O$@``+A(``"T2```L$@``*Q(``"H
M2```I$@``*!(``"<2```F$@``)1(``"02```C$@``(A(``"$2```@$@``'Q(
M``!X2```=$@``'!(``!L2```:$@``&1(``!@2```7$@``%A(``!42```4$@`
M`$Q(``!(2```1$@``$!(```\2```.$@``#1(```P2```+$@``"A(```D8```
M`&````!@````8````&````!@````8````&`````]@!`"/6OP`(`,K_@Y:Y9`
M?`D#IGP+6A2!C*_\?6!:%$Z`!"!@````8````&````!@````8````&````!@
M````E"'_\'P(`J:0`0`4D\$`"$*?``5_R`*F@`$`%'P(`Z:#P0`(."$`$$Z`
M`"``````$`(Q'!``$\`0`&2P$`!E<``"``%P97)L>'-I+F,```!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````0`&\L$`!O/!``;T00`&],
M$`!O5!``;V@`````$`!O)!``;$0`````$`!M'!``;2`0`&\8$`!L3!``;R``
M````$`!O!!``;PP`````68```````````````````$'/____@```)7,O)7,`
M```O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````
M4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!0
M15),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P``
M`%!!4E]#04-(10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"
M04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]
M```Q````4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L
M`````#````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````
M5$5-4$1)4@!435``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,
M24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!
M4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D
M14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I
M.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E
M14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIS
M965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N;&5S
M<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@
M)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I
M('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T
M.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY
M("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T
M*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M
M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D
M9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D
M(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY
M("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@
M:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A
M*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD
M,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H
M<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"([
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E
M:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L
M<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E
M*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@
M)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@
M(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*
M=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I
M;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F
M:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I
M9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O
M9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI
M<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E
M(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````$``7,!``%O``````$`&Q
M%!`!KMP0`:[8`````0````$````!```"!0````$```)4````#!``$WP````-
M$`!K$````!D0`:[8````&P````0````:$`&NW````!P````$;__^]1```8@`
M```%$``)@`````80``+@````"@``!1T````+````$````!4``````````Q`!
ML``````"```#,````!0````'````%Q``$$QP````$`&O]`````<0`!`$````
M"````W@````)````#&____X0``]T;____P````)O___P$``.G@``````````
M```````````````````````````````````````````````````````````0
M`:[P```````````0`&G`$`!IQ!``:<@0`&G,$`!IT!``:=00`&G8$`!IW!``
M:>`0`&GD$`!IZ!``:>P0`&GP$`!I]!``:?@0`&G\$`!J`!``:@00`&H($`!J
M#!``:A`0`&H4$`!J&!``:AP0`&H@$`!J)!``:B@0`&HL$`!J,!``:C00`&HX
M$`!J/!``:D`0`&I$$`!J2!``:DP0`&I0$`!J5!``:E@0`&I<$`!J8!``:F00
M`&IH$`!J;!``:G`0`&IT$`!J>!``:GP0`&J`$`!JA!``:H@0`&J,$`!JD!``
M:I00`&J8$`!JG!``:J`0`&JD$`!JJ!``:JP0`&JP$`!JM!``:K@0`&J\$`!J
MP!``:L00`&K($`!JS```````````_____Q``;W1'0T,Z("A58G5N='4@-"XY
M+C$M,39U8G5N='4U*2`T+CDN,0!'0T,Z("A58G5N='4@-"XX+C,M,3%U8G5N
M='4Q*2`T+C@N,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N
M;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YG;W0R`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M``````````````````````````````````````L````!`````A```30```$T
M````#0```````````````0`````````3````!P````(0``%$```!1````"``
M``````````````0`````````(0````<````"$``!9````60````D````````
M```````$`````````#1O___V`````A```8@```&(```!6`````4`````````
M!`````0````^````"P````(0``+@```"X```!J`````&`````0````0````0
M````1@````,````"$``)@```"8````4=```````````````!`````````$YO
M____`````A``#IX```Z>````U`````4``````````@````(```!;;____@``
M``(0``]T```/=````)`````&`````@````0`````````:@````0````"$``0
M!```$`0```!(````!0`````````$````#````'0````$````0A``$$P``!!,
M```#,`````4````6````!`````P```!^`````0````80`!-\```3?````$0`
M``````````````0`````````A`````$````&$``3P```$\```%=0````````
M```````@`````````(H````!````!A``:Q```&L0````+```````````````
M!`````````"0`````0````(0`&M```!K0```0#@```````````````@`````
M````F`````$````"$`"K>```JW@````$```````````````$`````````*(`
M```.`````Q`!KM@``*[8````!```````````````!`````````"N````#P``
M``,0`:[<``"NW`````0```````````````0`````````N@````$````#$`&N
MX```KN`````$```````````````$`````````+\````!`````Q`!KN0``*[D
M````#````````````````0````````#%````!@````,0`:[P``"N\````0``
M```&``````````0````(````S@````$````#$`&O\```K_`````0````````
M```````$````!````'D````!`````Q`!L````+`````!$```````````````
M!`````````#3`````0````,0`;$0``"Q$`````P```````````````0`````
M````V0````$````#$`&Q'```L1P````$```````````````$`````````.``
M```(`````Q`!L2```+$@```0.```````````````$`````````#E`````0``
M`#````````"Q(````$@```````````````$````!`````0````,`````````
9````L6@```#N```````````````!````````
